Struct GCGatewayController
pub struct GCGatewayController {
realtime_db: GCArcRealtimeDatabase,
message_broker: RwLock<GCMessageBroker>,
plugin_manager: RwLock<GCPluginManager<PluginInstanceHandler>>,
config_db: RwLock<GCConfigDatabase>,
device_config_manager: DeviceConfigManager,
broker_publisher: GCMessagePublisher,
timeseries: Mutex<GCTimeseriesConnection>,
}Expand description
The gateway controller manages the entire gateway and can be used to interact with the different components Any changes to the system should be done through this interface.
It is important to note that the concurrent message is not automatically started, the user must call the GCGatewayController::start_async_broker method
TODO: Make negations tests
Fields
realtime_db: GCArcRealtimeDatabasemessage_broker: RwLock<GCMessageBroker>plugin_manager: RwLock<GCPluginManager<PluginInstanceHandler>>config_db: RwLock<GCConfigDatabase>device_config_manager: DeviceConfigManagerbroker_publisher: GCMessagePublishertimeseries: Mutex<GCTimeseriesConnection>Implementations
impl GCGatewayController
impl GCGatewayController
pub(crate) fn new(
realtime_db: GCArcRealtimeDatabase,
message_broker: GCMessageBroker,
plugin_manager: GCPluginManager<PluginInstanceHandler>,
config_db: GCConfigDatabase,
timeseries: GCTimeseriesConnection,
) -> Self
pub(crate) fn new( realtime_db: GCArcRealtimeDatabase, message_broker: GCMessageBroker, plugin_manager: GCPluginManager<PluginInstanceHandler>, config_db: GCConfigDatabase, timeseries: GCTimeseriesConnection, ) -> Self
Creates a new instance of the gateway controller
The caller is responsible for ensuring the different components are synced between each other, if this is not true may lead to inconsistences (eg: a plugin instance being loaded with a wrong configuration)
pub fn timeseries_ref(&self) -> MutexGuard<'_, GCTimeseriesConnection>
pub fn get_config_db(&self) -> RwLockReadGuard<'_, GCConfigDatabase>
pub fn get_config_db(&self) -> RwLockReadGuard<'_, GCConfigDatabase>
Retrieve the config database, responsible for storing plugins config and datapoint information
pub fn get_message_broker(&self) -> RwLockReadGuard<'_, GCMessageBroker>
pub fn get_message_broker(&self) -> RwLockReadGuard<'_, GCMessageBroker>
Retrieve the message broker, responsible for managing the messaging pipelines
pub fn get_plugin_manager(
&self,
) -> RwLockReadGuard<'_, GCPluginManager<PluginInstanceHandler>>
pub fn get_plugin_manager( &self, ) -> RwLockReadGuard<'_, GCPluginManager<PluginInstanceHandler>>
Retrieve plugin manager, responsible for managing the plugin system
pub fn poll_timeseries(&self)
pub fn poll_timeseries(&self)
Flushes the buffered datapoint values to the timeseries database